@@ -17,21 +17,20 @@ pub mod mlp {
     tonic::include_proto!("mlp");
 }
 
-#[cfg(target_os = "windows")]
-pub mod engine;
 #[cfg(target_os = "windows")]
 pub mod cli;
+#[cfg(target_os = "windows")]
+pub mod server;
 
 /// initializes global logging backend that is used by log macros
 /// Takes in a filter for stdout/stderr, a filter for logfile and finally the path to logfile
-pub fn log_init_panic(
+pub fn log_init(
     term_filter: LevelFilter,
     file_filter: LevelFilter,
     file_path: PathBuf,
 ) -> anyhow::Result<()> {
     use simplelog::*;
     use std::fs::File;
-    human_panic::setup_panic!();
 
     CombinedLogger::init(vec![
         TermLogger::new(
@@ -40,11 +39,7 @@ pub fn log_init_panic(
             TerminalMode::Mixed,
             ColorChoice::Auto,
         ),
-        WriteLogger::new(
-            file_filter,
-            Config::default(),
-            File::create(file_path)?,
-        ),
+        WriteLogger::new(file_filter, Config::default(), File::create(file_path)?),
     ])?;
     Ok(())
 }
